<img src="https://github.com/ilya-smut/blue-book/blob/main/bluebook/static/images/book.svg" alt="blue book" width="170" height="115"/>

# Blue Book

Blue Book is an application that generates multiple-choice questions for CompTIA Security+ preparation at the press of a button. It uses the Gemini API to generate questions and provides instant feedback on answers.

## Features
- Generate CompTIA Security+ multiple-choice questions.
- Submit answers and receive immediate feedback.
- Explanation of correct and incorrect answers to enhance learning.

## Installation

You can install bluebook with pip:
   ```sh
   pip install student-bluebook
   ```

## Usage

Please see bluebook's interface and capabilities on this wiki page [wiki page](https://github.com/ilya-smut/blue-book/wiki/What-to-expect-from-Blue-Book-0.1.0%3F):

To start the application, use the following command:
```sh
bluebook start
```

## Contributing
If you’d like to contribute to Blue Book, feel free to submit a pull request or open an issue.

## License
This project is licensed under the GPLv3

## Contact
For any questions or feedback, feel free to reach out.

